@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.004';
+$Time::C::VERSION = '0.005';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -17,6 +17,7 @@ use Time::Piece ();
 use Time::Zone::Olson;
 
 
+
 method new ($c: $year = undef, $month = 1, $day = 1, $hour = 0, $minute = 0, $second = 0, $tz = 'UTC') {
     return $c->now_utc() if not defined $year;
 
@@ -36,7 +37,7 @@ method localtime ($c: $epoch, $tz = $ENV{TZ}) {
 method gmtime ($c: $epoch) { $c->localtime( $epoch, 'UTC' ); }
 
 
-method now ($c:) { $c->localtime( time ); }
+method now ($c: $tz = $ENV{TZ}) { $c->gmtime( time )->tz( $tz // 'UTC' ); }
 
 
 method now_utc ($c:) { $c->localtime( time, 'UTC' ); }
@@ -133,11 +134,18 @@ fun _parse ($str, $format = undef, $tz = 'UTC') {
 
 
 
-method epoch ($t:) :lvalue {
+method epoch ($t: $new_epoch = undef) :lvalue {
     my $epoch = _from_utc($t->{epoch}, $t->{tz});
 
-    sentinel value => $epoch, set =>
-      sub { $t->{epoch} = _to_utc($_[0], $t->{tz}); $_[0]; };
+    my $setter = sub {
+        $t->{epoch} = _to_utc($_[0], $t->{tz});
+        return $t if defined $new_epoch;
+        return $_[0];
+    };
+
+    return $setter->($new_epoch) if defined $new_epoch;
+
+    sentinel value => $epoch, set => $setter;
 }
 
 
@@ -162,7 +170,7 @@ method tz ($t: $new_tz = undef) :lvalue {
 }
 
 
-method offset ($t:) :lvalue {
+method offset ($t: $new_offset = undef) :lvalue {
     my $offset = eval { Time::Zone::Olson->new({timezone => $t->{tz}})
       ->local_offset($t->{epoch}); };
 
@@ -174,31 +182,56 @@ method offset ($t:) :lvalue {
         }
     }
 
+    my $setter = sub {
+        $t->{tz} = _get_tz($_[0]);
+
+        return $t if defined $new_offset;
+        return $_[0];
+    };
+
+    return $setter->($new_offset) if defined $new_offset;
+
     croak sprintf "Invalid timezone %s set. Can't find offset.", $t->{tz}
       if not defined $offset;
 
-    sentinel value => $offset, set =>
-      sub { $t->{tz} = _get_tz($_[0]); $_[0]; };
+    sentinel value => $offset, set => $setter;
 }
 
 
-method tm ($t:) :lvalue {
+method tm ($t: $new_tm = undef) :lvalue {
     $t->{tz} = 'UTC' if not defined $t->{tz};
 
+    my $setter = sub {
+        $t->{epoch} = $_[0]->with_offset_same_instant(0)->epoch;
+
+        return $t if defined $new_tm;
+        return $_[0];
+    };
+
+    return $setter->($new_tm) if defined $new_tm;
+
     my $tm = Time::Moment->from_epoch($t->{epoch});
 
     if ($t->{tz} ne 'GMT' and $t->{tz} ne 'UTC') {
         $tm = $tm->with_offset_same_instant($t->offset);
     }
 
-    sentinel value => $tm, set =>
-      sub { $t->{epoch} = $_[0]->with_offset_same_instant(0)->epoch; $_[0]; };
+    sentinel value => $tm, set => $setter;
 }
 
 
-method string ($t: $format = undef) :lvalue {
+method string ($t: $format = undef, $new_str = undef) :lvalue {
     $t->{tz} = 'UTC' if not defined $t->{tz};
 
+    my $setter = sub {
+        @{$t}{epoch,tz} = _parse($_[0], $format, $t->{tz});
+
+        return $t if defined $new_str;
+        return $_[0];
+    };
+
+    return $setter->($new_str) if defined $new_str;
+
     my $str;
     if (defined $format) {
         local $ENV{TZ} = $t->{tz};
@@ -208,151 +241,234 @@ method string ($t: $format = undef) :lvalue {
         $str = Time::Moment->from_epoch($t->{epoch})->with_offset_same_instant($t->offset)->to_string;
     }
 
-    sentinel value => $str, set =>
-      sub { @{$t}{epoch,tz} = _parse($_[0], $format, $t->{tz}); $_[0]; }
+    sentinel value => $str, set => $setter;
 }
 
 
-method year ($t:) :lvalue {
+method year ($t: $new_year = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->year, set =>
-      sub {
-          my $ret = ($t->tm = $tm->with_year($_[0]))->year;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->with_year($_[0]))->year;
+
+        return $t if defined $new_year;
+        return $ret;
+    };
+
+    return $setter->($new_year) if defined $new_year;
+
+    sentinel value => $tm->year, set => $setter;
 }
 
 
-method quarter ($t:) :lvalue {
+method quarter ($t: $new_quarter = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->quarter, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_months(3*$_[0] - $tm->month))->quarter;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_months(3*$_[0] - $tm->month))->quarter;
+
+        return $t if defined $new_quarter;
+        return $ret;
+    };
+
+    return $setter->($new_quarter) if defined $new_quarter;
+
+    sentinel value => $tm->quarter, set => $setter;
 }
 
 
-method month ($t:) :lvalue {
+method month ($t: $new_month = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->month, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_months($_[0] - $tm->month))->month;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_months($_[0] - $tm->month))->month;
+
+        return $t if defined $new_month;
+        return $ret;
+    };
+
+    return $setter->($new_month) if defined $new_month;
+
+    sentinel value => $tm->month, set => $setter;
 }
 
 
-method week ($t:) :lvalue {
+method week ($t: $new_week = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->week, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_weeks($_[0] - $tm->week))->week;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_weeks($_[0] - $tm->week))->week;
+
+        return $t if defined $new_week;
+        return $ret;
+    };
+
+    return $setter->($new_week) if defined $new_week;
+
+    sentinel value => $tm->week, set => $setter;
 }
 
 
-method day ($t:) :lvalue { $t->day_of_month }
+method day ($t: $new_day = undef) :lvalue { $t->day_of_month(@_) }
 
 
-method day_of_month ($t:) :lvalue {
+method day_of_month ($t: $new_day = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->day_of_month, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_month))->day_of_month;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_month))->day_of_month;
+
+        return $t if defined $new_day;
+        return $ret;
+    };
+
+    return $setter->($new_day) if defined $new_day;
+
+    sentinel value => $tm->day_of_month, set => $setter;
 }
 
 
-method day_of_year ($t:) :lvalue {
+method day_of_year ($t: $new_day = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->day_of_year, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_year))->day_of_year;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_year))->day_of_year;
+
+        return $t if defined $new_day;
+        return $ret;
+    };
+
+    return $setter->($new_day) if defined $new_day;
+
+    sentinel value => $tm->day_of_year, set => $setter;
 }
 
 
-method day_of_quarter ($t:) :lvalue {
+method day_of_quarter ($t: $new_day = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->day_of_quarter, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_quarter))->day_of_quarter;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_quarter))->day_of_quarter;
+
+        return $t if defined $new_day;
+        return $ret;
+    };
+
+    return $setter->($new_day) if defined $new_day;
+
+    sentinel value => $tm->day_of_quarter, set => $setter;
 }
 
 
-method day_of_week ($t:) :lvalue {
+method day_of_week ($t: $new_day = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->day_of_week, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_week))->day_of_week;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_days($_[0] - $tm->day_of_week))->day_of_week;
+
+        return $t if defined $new_day;
+        return $ret;
+    };
+
+    return $setter->($new_day) if defined $new_day;
+
+    sentinel value => $tm->day_of_week, set => $setter;
 }
 
 
-method hour ($t:) :lvalue {
+method hour ($t: $new_hour = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->hour, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_hours($_[0] - $tm->hour))->hour;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_hours($_[0] - $tm->hour))->hour;
+
+        return $t if defined $new_hour;
+        return $ret;
+    };
+
+    return $setter->($new_hour) if defined $new_hour;
+
+    sentinel value => $tm->hour, set => $setter;
 }
 
 
-method minute ($t:) :lvalue {
+method minute ($t: $new_minute = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->minute, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_minutes($_[0] - $tm->minute))->minute;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_minutes($_[0] - $tm->minute))->minute;
+
+        return $t if defined $new_minute;
+        return $ret;
+    };
+
+    return $setter->($new_minute) if defined $new_minute;
+
+    sentinel value => $tm->minute, set => $setter;
 }
 
 
-method second ($t:) :lvalue {
+method second ($t: $new_second = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->second, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_seconds($_[0] - $tm->second))->second;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_seconds($_[0] - $tm->second))->second;
+
+        return $t if defined $new_second;
+        return $ret;
+    };
+
+    return $setter->($new_second) if defined $new_second;
+
+    sentinel value => $tm->second, set => $setter;
 }
 
 
-method millisecond ($t:) :lvalue {
+method millisecond ($t: $new_msec = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->millisecond, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_milliseconds($_[0] - $tm->millisecond))->millisecond;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_milliseconds($_[0] - $tm->millisecond))->millisecond;
+
+        return $t if defined $new_msec;
+        return $ret;
+    };
+
+    return $setter->($new_msec) if defined $new_msec;
+
+    sentinel value => $tm->millisecond, set => $setter;
 }
 
 
-method microsecond ($t:) :lvalue {
+method microsecond ($t: $new_msec = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->microsecond, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_microseconds($_[0] - $tm->microsecond))->microsecond;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_microseconds($_[0] - $tm->microsecond))->microsecond;
+
+        return $t if defined $new_msec;
+        return $ret;
+    };
+
+    return $setter->($new_msec) if defined $new_msec;
+
+    sentinel value => $tm->microsecond, set => $setter;
 }
 
 
-method nanosecond ($t:) :lvalue {
+method nanosecond ($t: $new_nsec = undef) :lvalue {
     my $tm = $t->tm();
 
-    sentinel value => $tm->nanosecond, set =>
-      sub {
-          my $ret = ($t->tm = $tm->plus_nanoseconds($_[0] - $tm->nanosecond))->nanosecond;
-      };
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_nanoseconds($_[0] - $tm->nanosecond))->nanosecond;
+
+        return $t if defined $new_nsec;
+        return $ret;
+    };
+
+    return $setter->($new_nsec) if defined $new_nsec;
+
+    sentinel value => $tm->nanosecond, set => $setter;
 }
 
 1;
@@ -369,7 +485,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -416,27 +532,27 @@ Creates a Time::C object for the specified time, or the current time if no C<$ye
 
 =item C<$year>
 
-This is the year. If not specified, C<new()> will call C<now_utc()>.
+This is the year. If not specified, C<new()> will call C<now_utc()>. The year is 1-based and starts with year 1 corresponding to 1 AD. Legal values are in the range 1-9999.
 
 =item C<$month>
 
-This is the month. If not specified it defaults to C<1>.
+This is the month. If not specified it defaults to C<1>. The month is 1-based and starts with month 1 corresponding to January. Legal values are in the range 1-12.
 
 =item C<$day>
 
-This is the day of the month. If not specified it defaults to C<1>.
+This is the day of the month. If not specified it defaults to C<1>. The day is 1-based and starts with day 1 being the first day of the month. Legal values are in the range 1-31.
 
 =item C<$hour>
 
-This is the hour. If not specified it defaults to C<0>.
+This is the hour. If not specified it defaults to C<0>. The hour is 0-based and starts with hour 0 corresponding to midnight. Legal values are in the range 0-23.
 
 =item C<$minute>
 
-This is the minute. If not specified it defaults to C<0>.
+This is the minute. If not specified it defaults to C<0>. The minute is 0-based and starts with minute 0 being the first minute of the hour. Legal values are in the range 0-59.
 
 =item C<$second>
 
-This is the second. If not specified it defaults to C<0>.
+This is the second. If not specified it defaults to C<0>. The second is 0-based and starts with second 0 being the first second of the minute. Legal values are in the range 0-59.
 
 =item C<$tz>
 
@@ -480,8 +596,9 @@ This is the time in seconds since the system epoch, usually C<1970-01-01T00:00:0
 =head2 now
 
   my $t = Time::C->now();
+  my $t = Time::C->now($tz);
 
-Creates a Time::C object for the current epoch in the timezone specified in C<$ENV{TZ}> or C<UTC> if that is unspecified.
+Creates a Time::C object for the current epoch in the timezone specified in C<$tz> or C<$ENV{TZ}> or C<UTC> if the first two are unspecified.
 
 =head2 now_utc
 
@@ -531,6 +648,8 @@ If the parsed time contains a zone or offset that parses, and the offset matches
 
 These accessors will work as C<LVALUE>s, meaning you can assign to them to change the time being represented.
 
+Note that an assignment expression will return the I<computed> value rather than the assigned value. This means that in the expression C<< my $wday = $t->day_of_week = 8; >> the value assigned to C<$wday> will be C<1> because the value returned from the day_of_week assignment wraps around after 7, and in fact starts the subsequent week. Similarly in the expression C<< my $mday = $t->month(2)->day_of_month = 30; >> the value assigned to C<$mday> will be either C<1> or C<2> depending on if it's a leap year or not, and the month will have changed to C<3>.
+
 =head2 epoch
 
   my $epoch = $t->epoch;
@@ -539,8 +658,12 @@ These accessors will work as C<LVALUE>s, meaning you can assign to them to chang
   $t->epoch++;
   $t->epoch--;
 
+  $t = $t->epoch($new_epoch);
+
 Returns or sets the epoch according to the specified timezone.
 
+If the form C<< $t->epoch($new_epoch) >> is used, it likewise changes the epoch but returns the entire object.
+
 =head2 tz
 
   my $tz = $t->tz;
@@ -550,7 +673,7 @@ Returns or sets the epoch according to the specified timezone.
 
 Returns or sets the timezone. If the timezone can't be recognised it dies.
 
-If the form C<< $t->tz($new_tz) >> is used, it instead changes the internal tz and returns the entire object.
+If the form C<< $t->tz($new_tz) >> is used, it likewise changes the timezone but returns the entire object.
 
 =head2 offset
 
@@ -558,15 +681,23 @@ If the form C<< $t->tz($new_tz) >> is used, it instead changes the internal tz a
   $t->offset = $offset;
   $t->offset += 60;
 
+  $t = $t->offset($new_offset);
+
 Returns or sets the current offset in minutes. If the offset is set, it tries to find a generic C<Etc/GMT+X> or C<+XX:XX> timezone that matches the offset and updates the C<tz> to this. If it fails, it dies with an error.
 
+If the form C<< $t->offset($new_offset) >> is used, it likewise sets the timezone from C<$new_offset> but returns the entire object.
+
 =head2 tm
 
   my $tm = $t->tm;
   $t->tm = $tm;
 
+  $t = $t->tm($new_tm);
+
 Returns a Time::Moment object for the current epoch and offset. On setting, it changes the current epoch.
 
+If the form C<< $t->tm($new_tm) >> is used, it likewise changes the current epoch but returns the entire object.
+
 =head2 string
 
   my $str = $t->string;
@@ -574,8 +705,12 @@ Returns a Time::Moment object for the current epoch and offset. On setting, it c
   $t->string = $str;
   $t->string($format) = $str;
 
+  $t = $t->string($format, $new_str);
+
 Renders the current time to a string using the optional strftime C<$format>. If the C<$format> is not given it defaults to C<undef>. When setting this value, it tries to parse the string using L<Time::Piece/strptime> with the C<$format> or L<Time::Moment/from_string> if no C<$format> was given or strptime fails. If the detected C<offset> matches the current C<tz>, that is kept, otherwise it will get changed to a generic C<tz> in the form of C<Etc/GMT+X> or C<+XX:XX>.
 
+If the form C<< $t->string($format, $new_str) >> is used, it likewise updates the epoch and timezone but returns the entire object.
+
 =head2 year
 
   my $year = $t->year;
@@ -584,8 +719,14 @@ Renders the current time to a string using the optional strftime C<$format>. If
   $t->year++;
   $t->year--;
 
+  $t = $t->year($new_year);
+
 Returns or sets the current year, updating the epoch accordingly.
 
+If the form C<< $t->year($new_year) >> is used, it likewise sets the current year but returns the entire object.
+
+The year is 1-based where the year 1 corresponds to 1 AD. Legal values are in the range 1-9999.
+
 =head2 quarter
 
   my $quarter = $t->quarter;
@@ -594,8 +735,14 @@ Returns or sets the current year, updating the epoch accordingly.
   $t->quarter++;
   $t->quarter--;
 
+  $t = $t->quarter($new_quarter);
+
 Returns or sets the current quarter of the year, updating the epoch accordingly.
 
+If the form C<< $t->quarter($new_quarter) >> is used, it likewise sets the current quarter but returns the entire object.
+
+The quarter is 1-based where quarter 1 is the first three months of the year. Legal values are in the range 1-4.
+
 =head2 month
 
   my $month = $t->month;
@@ -604,8 +751,14 @@ Returns or sets the current quarter of the year, updating the epoch accordingly.
   $t->month++;
   $t->month--;
 
+  $t = $t->month($new_month);
+
 Returns or sets the current month of the year, updating the epoch accordingly.
 
+If the form C<< $t->month($new_month) >> is used, it likewise sets the month but returns the entire object.
+
+The month is 1-based where month 1 is January. Legal values are in the range 1-12.
+
 =head2 week
 
   my $week = $t->week;
@@ -614,8 +767,14 @@ Returns or sets the current month of the year, updating the epoch accordingly.
   $t->week++;
   $t->week--;
 
+  $t = $t->week($new_week);
+
 Returns or sets the current week or the year, updating the epoch accordingly.
 
+If the form C<< $t->week($new_week) >> is used, it likewise sets the current week but returns the entire object.
+
+The week is 1-based where week 1 is the first week of the year according to ISO 8601. The first week may actually have some days in the previous year, and the last week may have some days in the subsequent year. Legal values are in the range 1-53.
+
 =head2 day
 
   my $day = $t->day;
@@ -624,8 +783,14 @@ Returns or sets the current week or the year, updating the epoch accordingly.
   $t->day++;
   $t->day--;
 
+  $t = $t->day($new_day);
+
 Returns or sets the current day of the month, updating the epoch accordingly.
 
+If the form C<< $t->day($new_day) >> is used, it likewise sets the current day of the month but returns the entire object.
+
+The day is 1-based where day 1 is the first day of the month. Legal values are in the range 1-31.
+
 =head2 day_of_month
 
 Functions exactly like C<day>.
@@ -638,7 +803,13 @@ Functions exactly like C<day>.
   $t->day_of_year++;
   $t->day_of_year--;
 
-Returns or sets the current day of the month, updating the epoch accordingly.
+  $t = $t->day_of_year($new_day);
+
+Returns or sets the current day of the year, updating the epoch accordingly.
+
+If the form C<< $t->day_of_year($new_day) >> is used, it likewise sets the current day of the year but returns the entire object.
+
+The day is 1-based where day 1 is the first day of the year. Legal values are in the range 1-366.
 
 =head2 day_of_quarter
 
@@ -648,8 +819,14 @@ Returns or sets the current day of the month, updating the epoch accordingly.
   $t->day_of_quarter++;
   $t->day_of_quarter--;
 
+  $t = $t->day_of_quarter($new_day);
+
 Returns or sets the current day of the quarter, updating the epoch accordingly.
 
+If the form C<< $t->day_of_quarter($new_day) >> is used, it likewise sets the current day of the quarter but returns the entire object.
+
+The day is 1-based where day 1 is the first day in the first month of the quarter. Legal values are in the range 1-92.
+
 =head2 day_of_week
 
   my $wday = $t->day_of_week;
@@ -658,8 +835,14 @@ Returns or sets the current day of the quarter, updating the epoch accordingly.
   $t->day_of_week++;
   $t->day_of_week--;
 
+  $t = $t->day_of_week($new_day);
+
 Returns or sets the current day of the week, updating the epoch accordingly. This module uses L<Time::Moment> which counts days in the week starting from 1 with Monday, and ending on 7 with Sunday.
 
+If the form C<< $t->day_of_week($new_day) >> is used, it likewise sets the current day of the week but returns the entire object.
+
+The day is 1-based where day 1 is Monday. Legal values are in the range 1-7.
+
 =head2 hour
 
   my $hour = $t->hour;
@@ -668,8 +851,14 @@ Returns or sets the current day of the week, updating the epoch accordingly. Thi
   $t->hour++;
   $t->hour--;
 
+  $t = $t->hour($new_hour);
+
 Returns or sets the current hour of the day, updating the epoch accordingly.
 
+If the form C<< $t->hour($new_hour) >> is used, it likewise sets the current hour but returns the entire object.
+
+The hour is 0-based where hour 0 is midnight. Legal values are in the range 0-23.
+
 =head2 minute
 
   my $minute = $t->minute;
@@ -678,8 +867,14 @@ Returns or sets the current hour of the day, updating the epoch accordingly.
   $t->minute++;
   $t->minute--;
 
+  $t = $t->minute($new_minute);
+
 Returns or sets the current minute of the hour, updating the epoch accordingly.
 
+If the form C<< $t->minute($new_minute) >> is used, it likewise sets the current minute but returns the entire object.
+
+The minute is 0-based where minute 0 is the first minute of the hour. Legal values are in the range 0-59.
+
 =head2 second
 
   my $second = $t->second;
@@ -688,8 +883,14 @@ Returns or sets the current minute of the hour, updating the epoch accordingly.
   $t->second++;
   $t->second--;
 
+  $t = $t->second($new_second);
+
 Returns or sets the current second of the minute, updating the epoch accordingly.
 
+If the form C<< $t->second($new_second) >> is used, it likewise sets the current second but returns the entire object.
+
+The second is 0-based where second 0 is the first second of the minute. Legal values are in the range 0-59.
+
 =head2 millisecond
 
   my $msec = $t->millisecond;
@@ -698,8 +899,14 @@ Returns or sets the current second of the minute, updating the epoch accordingly
   $t->millisecond++;
   $t->millisecond--;
 
+  $t = $t->millisecond($new_msec);
+
 Returns or sets the current millisecond of the second, updating the epoch accordingly.
 
+If the form C<< $t->millisecond($new_msec) >> is used, it likewise updates the current millisecond but returns the entire object.
+
+The millisecond is 0-based where millisecond 0 means exact to the second. Legal values are in the range 0-999.
+
 =head2 microsecond
 
   use utf8;
@@ -709,8 +916,14 @@ Returns or sets the current millisecond of the second, updating the epoch accord
   $t->microsecond++;
   $t->microsecond--;
 
+  $t = $t->microsecond($new_µsec);
+
 Returns or sets the current microsecond of the second, updating the epoch accordingly.
 
+If the form C<< $t->microsecond($new_µsec) >> is used, it likewise updates the current microsecond but returns the entire object.
+
+The microsecond is 0-based where microsecond 0 means exact to the second. Legal values are in the range 0-999'999.
+
 =head2 nanosecond
 
   my $nsec = $t->nanosecond;
@@ -719,8 +932,14 @@ Returns or sets the current microsecond of the second, updating the epoch accord
   $t->nanosecond++;
   $t->nanosecond--;
 
+  $t = $t->nanosecond($new_nsec);
+
 Returns or sets the current nanosecond of the second, updating the epoch accordingly.
 
+If the form C<< $t->nanosecond($new_nsec) >> is used, it likewise updates the current nanosecond but returns the entire object.
+
+The nanosecond is 0-based where nanosecond 0 means exact to the second. Legal values are in the range 0-999'999'999.
+
 =head1 SEE ALSO
 
 =over
