@@ -1,5 +1,7 @@
+use strict;
+use warnings;
 package Time::C::Sentinel;
-$Time::C::Sentinel::VERSION = '0.004';
+$Time::C::Sentinel::VERSION = '0.005';
 use Exporter qw/ import /;
 
 our @EXPORT = qw/ sentinel /;
@@ -43,7 +45,7 @@ Time::C::Sentinel
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
